==> release.12.0.73.1.tgz: prontus/cpan/js-local/Fechas.class.js <==
// Funciones de manejo de fechas en fids.
var Fechas = {
    objFormFid: '', // se setea en el doc. ready

    meses: ['enero','febrero','marzo','abril','mayo','junio', 'julio','agosto','septiembre','octubre','noviembre','diciembre'],
    dias: ['Domingo','Lunes','Martes','Miércoles','Jueves','Viernes','Sábado'],

    w2: function(num,n) {
        var a = num + '';
        while (a.length < n) {
            a = '0' + a;
        }
        return a;
    },

    validaFechaText: function(texto) {
        var datearray = texto.split('/');
        if ( isNaN(datearray[0]) || isNaN(datearray[1]) || isNaN(datearray[2]) ||
                (datearray[0] < 1) || (datearray[0] > 31) ||
                (datearray[1] < 1) || (datearray[1] > 12) ||
                (datearray[2] < 1) || (datearray[2] > 3000)) {
            return 0;
        } else {
            return 1;
        }
    },

    text2date: function(texto) {
        var datearray = texto.split('/');
        if (datearray[2] < 100) {
            datearray[2] = datearray[2] * 1 + 2000;
        }
        var date = new Date(datearray[2],(datearray[1] - 1),datearray[0],2,0,0); // 1.1
        return date;
    },

    date2iso: function(fechadate) {
        var ano = fechadate.getYear();
        if (ano < 200) { // onda 103, NS70
            ano = ano + 1900;
        }

        ano = Fechas.w2(ano,4);

        var mes = Fechas.w2(1 + fechadate.getMonth(),2);
        var dia = Fechas.w2(fechadate.getDate(),2);
        return ano + mes + dia + '';
    },

    date2text: function(fechadate) {
        var ano = fechadate.getYear();
        if (ano < 200) { // onda 103, NS70
            ano = ano + 1900;
        }

        ano = Fechas.w2(ano,4);

        var mes = Fechas.w2(1 + fechadate.getMonth(),2);
        var dia = Fechas.w2(fechadate.getDate(),2);
        return dia + '/' + mes + '/' + ano;
    },

    iso2date: function(iso) {
        if (iso.length == 8) {
            var ano = 0 + iso.substring(0,4);
            var mes = 0 + iso.substring(4,6);
            var dia = 0 + iso.substring(6);
            var date=new Date();
            date.setFullYear(ano,(mes - 1),dia);
            return date;
        }else{
            return Date();
        }
    },

    iso2longdate: function(iso) {
        var date = new Date();
        var ano;
        var mes;
        var dia;
        if (iso.length == 8) {
            ano = 1 * iso.substring(0,4);
            mes = 1 * iso.substring(4,6);
            dia = 1 * iso.substring(6);
            // var date = new Date(ano,(mes - 1),dia);
            date.setFullYear(ano,(mes - 1),dia);
        } else {
            ano = date.getDate();
            mes = date.getMonth();
            dia = date.getYear();
        }
        var diasem = Fechas.dias[date.getDay()];
        var mes2 = Fechas.meses[mes - 1];
        return diasem + ', ' + dia + ' de ' + mes2 + ' de ' + ano;
    },

    fillfechashrt: function() {
        var theForm = Fechas.objFormFid;
        // Llena fechapshrt en base a fechap
        if (typeof(theForm._FECHAP) !== 'undefined') {
            var fechap = theForm._FECHAP.value;
            if (fechap == '99999999') {
                theForm._FECHAPSHRT.value = '';
            } else {
                var date;
                if (fechap === '') {
                    date = new Date();
                } else {
                    date = Fechas.iso2date(fechap);
                }
                theForm._FECHAPSHRT.value = Fechas.date2text(date);
            }
        }

        // Llena fechaeshrt en base a fechae
        if (typeof(theForm._FECHAE) !== 'undefined') {
            var fechae = theForm._FECHAE.value;
            if (fechae == '99999999') {
                theForm._FECHAESHRT.value = '';
            } else {
                if (fechae === '') {
                    theForm._FECHAESHRT.value = '';
                }else{
                    let date2 = Fechas.iso2date(fechae);
                    theForm._FECHAESHRT.value = Fechas.date2text(date2);
                }

            }
        }

        // Llena _fecha_inicio en base a _fecha_ini
        if (typeof(theForm._fecha_ini) !== 'undefined') {
            let fecha = theForm._fecha_ini.value;
            if (fecha === '') {
                document.getElementById('fecha_inicio').value = '';
            } else {
                let date2 = Fechas.iso2date(fecha);
                document.getElementById('fecha_inicio').value = Fechas.date2text(date2);
            }
        }

        // LLena _fecha_fin en base a _fecha_fin
        if (typeof(theForm._fecha_fin) !== 'undefined') {
            let fecha = theForm._fecha_fin.value;
            if (fecha === '') {
                document.getElementById('fecha_fin').value = '';
            } else {
                let date2 = Fechas.iso2date(fecha);
                document.getElementById('fecha_fin').value = Fechas.date2text(date2);
            }
        }
    },

    parseaFecha: function(fechashrt) {
        if (fechashrt === '') { return ''; }
        var iso = '';
        if (Fechas.validaFechaText(fechashrt)) {
            var date = Fechas.text2date(fechashrt);
            iso = Fechas.date2iso(date);
        }
        return iso;
    },

    fillfecha: function() {
        var theForm = Fechas.objFormFid;
        if (typeof(theForm._FECHAP) != 'undefined') {
            theForm._FECHAP.value = Fechas.parseaFecha(theForm._FECHAPSHRT.value);
        }

        if (typeof(theForm._FECHAE) != 'undefined') {
            theForm._FECHAE.value = Fechas.parseaFecha(theForm._FECHAESHRT.value);
        }

        if (typeof(theForm._fecha_fin) != 'undefined') {
            theForm._fecha_fin.value = Fechas.parseaFecha(document.getElementById('fecha_fin').value);
        }

        if (typeof(theForm._fecha_ini) != 'undefined') {
             theForm._fecha_ini.value = Fechas.parseaFecha(document.getElementById('fecha_inicio').value);
        }
    },

    // Llena el campo hora con la hora actual
    fillHora: function(noreemp) {
        var theForm = Fechas.objFormFid;
        if (typeof(theForm._HORAP) !== 'undefined') {
            if (theForm._HORAP.value === '') {
                var date = new Date();
                var hora = '' + date.getHours();
                var min = '' + date.getMinutes();
                if (hora.length < 2) { hora = '0' + hora; }
                if (min.length < 2) { min = '0' + min; }
                theForm._HORAP.value = hora + ':' + min;
            }
        }

        if (typeof(theForm._HORAE) !== 'undefined') {
            if (theForm._FECHAE.value === '' || theForm._FECHAE.value == '99999999') {
                theForm._HORAE.value = '';
            }
        }
    }
};

==> release.12.2.28.1.tgz: prontus/cpan/js-local/Fechas.class.js <==
// Funciones de manejo de fechas en fids.
var Fechas = {
    objFormFid: '', // se setea en el doc. ready

    meses: ['enero','febrero','marzo','abril','mayo','junio', 'julio','agosto','septiembre','octubre','noviembre','diciembre'],
    dias: ['Domingo','Lunes','Martes','Miércoles','Jueves','Viernes','Sábado'],

    w2: function(num,n) {
        var a = num + '';
        while (a.length < n) {
            a = '0' + a;
        }
        return a;
    },

    validaFechaText: function(texto) {
        var datearray = texto.split('/');
        if ( isNaN(datearray[0]) || isNaN(datearray[1]) || isNaN(datearray[2]) ||
                (datearray[0] < 1) || (datearray[0] > 31) ||
                (datearray[1] < 1) || (datearray[1] > 12) ||
                (datearray[2] < 1) || (datearray[2] > 3000)) {
            return 0;
        } else {
            return 1;
        }
    },

    text2date: function(texto) {
        var datearray = texto.split('/');
        if (datearray[2] < 100) {
            datearray[2] = datearray[2] * 1 + 2000;
        }
        var date = new Date(datearray[2],(datearray[1] - 1),datearray[0],2,0,0); // 1.1
        return date;
    },

    date2iso: function(fechadate) {
        var ano = fechadate.getYear();
        if (ano < 200) { // onda 103, NS70
            ano = ano + 1900;
        }

        ano = Fechas.w2(ano,4);

        var mes = Fechas.w2(1 + fechadate.getMonth(),2);
        var dia = Fechas.w2(fechadate.getDate(),2);
        return ano + mes + dia + '';
    },

    date2text: function(fechadate) {
        var ano = fechadate.getYear();
        if (ano < 200) { // onda 103, NS70
            ano = ano + 1900;
        }

        ano = Fechas.w2(ano,4);

        var mes = Fechas.w2(1 + fechadate.getMonth(),2);
        var dia = Fechas.w2(fechadate.getDate(),2);
        return dia + '/' + mes + '/' + ano;
    },

    iso2date: function(iso) {
        if (iso.length == 8) {
            var ano = 0 + iso.substring(0,4);
            var mes = 0 + iso.substring(4,6);
            var dia = 0 + iso.substring(6);
            var date=new Date();
            date.setFullYear(ano,(mes - 1),dia);
            return date;
        }else{
            return Date();
        }
    },

    iso2longdate: function(iso) {
        var date = new Date();
        var ano;
        var mes;
        var dia;
        if (iso.length == 8) {
            ano = 1 * iso.substring(0,4);
            mes = 1 * iso.substring(4,6);
            dia = 1 * iso.substring(6);
            // var date = new Date(ano,(mes - 1),dia);
            date.setFullYear(ano,(mes - 1),dia);
        } else {
            ano = date.getDate();
            mes = date.getMonth();
            dia = date.getYear();
        }
        var diasem = Fechas.dias[date.getDay()];
        var mes2 = Fechas.meses[mes - 1];
        return diasem + ', ' + dia + ' de ' + mes2 + ' de ' + ano;
    },

    fillfechashrt: function() {
        var theForm = Fechas.objFormFid;
        // Llena fechapshrt en base a fechap
        if (typeof(theForm._fechap) !== 'undefined') {
            var fechap = theForm._fechap.value;
            if (fechap == '99999999') {
                theForm._fechapshrt.value = '';
            } else {
                var date;
                if (fechap === '') {
                    date = new Date();
                } else {
                    date = Fechas.iso2date(fechap);
                }
                theForm._fechapshrt.value = Fechas.date2text(date);
            }
        }

        // Llena fechaeshrt en base a fechae
        if (typeof(theForm._fechae) !== 'undefined') {
            var fechae = theForm._fechae.value;
            if (fechae == '99999999') {
                theForm._fechaeshrt.value = '';
            } else {
                if (fechae === '') {
                    theForm._fechaeshrt.value = '';
                }else{
                    let date2 = Fechas.iso2date(fechae);
                    theForm._fechaeshrt.value = Fechas.date2text(date2);
                }

            }
        }

        // Llena _fecha_inicio en base a _fecha_ini
        if (typeof(theForm._fecha_ini) !== 'undefined') {
            let fecha = theForm._fecha_ini.value;
            if (fecha === '') {
                document.getElementById('fecha_inicio').value = '';
            } else {
                let date2 = Fechas.iso2date(fecha);
                document.getElementById('fecha_inicio').value = Fechas.date2text(date2);
            }
        }

        // LLena _fecha_fin en base a _fecha_fin
        if (typeof(theForm._fecha_fin) !== 'undefined') {
            let fecha = theForm._fecha_fin.value;
            if (fecha === '') {
                document.getElementById('fecha_fin').value = '';
            } else {
                let date2 = Fechas.iso2date(fecha);
                document.getElementById('fecha_fin').value = Fechas.date2text(date2);
            }
        }
    },

    parseaFecha: function(fechashrt) {
        if (fechashrt === '') { return ''; }
        var iso = '';
        if (Fechas.validaFechaText(fechashrt)) {
            var date = Fechas.text2date(fechashrt);
            iso = Fechas.date2iso(date);
        }
        return iso;
    },

    fillfecha: function() {
        var theForm = Fechas.objFormFid;
        if (typeof(theForm._fechap) != 'undefined') {
            theForm._fechap.value = Fechas.parseaFecha(theForm._fechapshrt.value);
        }

        if (typeof(theForm._fechae) != 'undefined') {
            theForm._fechae.value = Fechas.parseaFecha(theForm._fechaeshrt.value);
        }

        if (typeof(theForm._fecha_fin) != 'undefined') {
            theForm._fecha_fin.value = Fechas.parseaFecha(document.getElementById('fecha_fin').value);
        }

        if (typeof(theForm._fecha_ini) != 'undefined') {
             theForm._fecha_ini.value = Fechas.parseaFecha(document.getElementById('fecha_inicio').value);
        }
    },

    // Llena el campo hora con la hora actual
    fillHora: function(noreemp) {
        var theForm = Fechas.objFormFid;
        if (typeof(theForm._horap) !== 'undefined') {
            if (theForm._horap.value === '') {
                var date = new Date();
                var hora = '' + date.getHours();
                var min = '' + date.getMinutes();
                if (hora.length < 2) { hora = '0' + hora; }
                if (min.length < 2) { min = '0' + min; }
                theForm._horap.value = hora + ':' + min;
            }
        }

        if (typeof(theForm._horae) !== 'undefined') {
            if (theForm._fechae.value === '' || theForm._fechae.value == '99999999') {
                theForm._horae.value = '';
            }
        }
    }
};
